Str Namespace
| Type/Module | Description |
|
This module is automatically opened when the namespace Str is opened.
It provides a computational expression for building strings called |
|
|
Extension methods for System.String. Like DoesNotContain(str),.., This module is automatically opened when the namespace Str is opened. |
|
|
Extension methods for StringBuilder. Provides IndexOf methods and append operations that return unit. This module is automatically opened when the namespace Str is opened. |
|
|
Extension methods for System.String. Adds extension members on System.String. E.G. .First, .Second, .Last and similar indices. Also adds functionality for negative indices, and s.SliceNeg, s.SliceIdx and s.SliceLooped with an inclusive end index. This module is NOT automatically opened when the namespace Str is opened. |
|
|
The main module with functions for transforming strings. |
Str