AutoOpenComputationalExpression Module
This module is automatically opened when the namespace Str is opened.
It provides a computational expression for building strings called str.
Functions and values
| Function or value |
Description
|
|
Computational Expression String Builder: use 'yield' to append text, or a sequence of strings with a new line appended after every item, including the last, and 'yield!' (with an exclamation mark) to append text followed by a new line character. Accepts ints, GUIDs, and chars too.
|
Str