Logo Str

ComputationalExpressions Module

Types

Type Description

StringBufferBuilder

Computational Expression String Builder: use 'yield' to append text, or a sequence of strings with a new line appended after every item, including the last, and 'yield!' (with an exclamation mark) to append text followed by a new line character. Accepts ints, GUIDs, and chars too.

Type something to start searching.